==> matrix_input-1.0.0.tar.gz: README.md <==
# matrix_input

A package that leverages on the power of flutter widgets to display data in matrix form.

# Getting Started

Instead of hard coding the widgets to represent matrices, let this package make life bearable for you!

# Features

Use this package in your flutter app to:

* Place data i.e. numbers in matrix form.
* Perform arithmetic operations.
* Build puzzles which requires numbers displayed in matrix form.
* Teach i.e. perfect squares.

# Setup

Import it in your project:

import 'package:matrix_input/matrix_input.dart';

# Usage Examples

- 1x3 Matrix

![pic4](https://user-images.githubusercontent.com/19472506/119970378-507a1d80-bfb8-11eb-82d6-984520f8427e.jpg)


class _MatrixState extends State<Matrix> {
  TextEditingController r0c0;
  TextEditingController r0c1;
  TextEditingController r0c2;
  @override
  void initState() {
    //Initialize controllers i.e. matrix controllers
    r0c0 = TextEditingController();
    r0c1 = TextEditingController();
    r0c2 = TextEditingController();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('matrix_input'),
      ),
      body: Center(
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            MatrixInput(
              textAlign: TextAlign.center,
              enabled: true,
              readOnly: false,
              width: 60,
              matrixController: r0c0,
              keyboardType: TextInputType.number,
              style: TextStyle(
                fontSize: 25.0,
                color: Colors.red,
                fontWeight: FontWeight.bold,
              ),
            ),
            SizedBox(
              width: 5.0,
            ),
            MatrixInput(
              textAlign: TextAlign.center,
              enabled: true,
              readOnly: false,
              width: 60,
              matrixController: r0c1,
              keyboardType: TextInputType.number,
              style: TextStyle(
                fontSize: 25.0,
                color: Colors.purple,
                fontWeight: FontWeight.bold,
              ),
            ),
            SizedBox(
              width: 5.0,
            ),
            MatrixInput(
              textAlign: TextAlign.center,
              enabled: true,
              readOnly: false,
              width: 60,
              matrixController: r0c2,
              keyboardType: TextInputType.number,
              style: TextStyle(
                fontSize: 25.0,
                color: Colors.green,
                fontWeight: FontWeight.bold,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

- 3x3 Matrix

![pic1](https://user-images.githubusercontent.com/19472506/119970345-46f0b580-bfb8-11eb-982f-9d5b60bf13f9.png)

- 4x4 Matrix

![pic2](https://user-images.githubusercontent.com/19472506/119970363-4c4e0000-bfb8-11eb-84bd-39bd6037bd0d.png)


- 5x5 Matrix

![pic3](https://user-images.githubusercontent.com/19472506/119970375-4f48f080-bfb8-11eb-950f-cf7b9eafba0f.png)

Most importantly, bundle it in either a row or column.

Note: the "matrixController" is required. Just like a normal TextEditingController.

Thus, declare your TextEditingController textEditingController;

Make sure to initialize it in the init() section. Refer to example folder.

==> matrix_input-1.0.1.tar.gz: README.md <==
# matrix_input

A package that leverages on the power of flutter widgets to display data in matrix form.

# Getting Started

Instead of hard coding the widgets to represent matrices, let this package make life bearable for you!

# Features

Use this package in your flutter app to:

* Place data i.e. numbers in matrix form.
* Perform arithmetic operations.
* Build puzzles which requires numbers displayed in matrix form.
* Teach i.e. perfect squares.

# Setup

Import it in your project:

```dart: 
import 'package:matrix_input/matrix_input.dart';
```

Most importantly, bundle it in either a row or column.

Note: the "matrixController" is required. Just like a normal TextEditingController.

Thus, declare your TextEditingController textEditingController; i.e TextEditingController r0c0;
Implying Row1Column0 e.t.c

Make sure to initialize it in the init() section. Refer to example folder.

# Usage Examples

- 1x3 Matrix

![pic1](https://user-images.githubusercontent.com/19472506/120332238-382b3b00-c2f7-11eb-84db-ea2063fc5b29.png)

```dart:
class _MatrixState extends State<Matrix> {
  TextEditingController r0c0;
  TextEditingController r0c1;
  TextEditingController r0c2;
  @override
  void initState() {
    //Initialize controllers i.e. matrix controllers
    r0c0 = TextEditingController(text: '8');
    r0c1 = TextEditingController(text: '9');
    r0c2 = TextEditingController(text: "10");
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('matrix_input'),
      ),
      body: Center(
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            MatrixInput(
              matrixBorderColor: Colors.red,
              textAlign: TextAlign.center,
              enabled: true,
              readOnly: false,
              width: 60,
              matrixController: r0c0,
              keyboardType: TextInputType.number,
              style: TextStyle(
                fontSize: 25.0,
                color: Colors.blueAccent,
                fontWeight: FontWeight.bold,
              ),
            ),
            SizedBox(
              width: 5.0,
            ),
            MatrixInput(
              matrixBorderColor: Colors.yellow,
              textAlign: TextAlign.center,
              enabled: true,
              readOnly: false,
              width: 60,
              matrixController: r0c1,
              keyboardType: TextInputType.number,
              style: TextStyle(
                fontSize: 25.0,
                color: Colors.purple,
                fontWeight: FontWeight.bold,
              ),
            ),
            SizedBox(
              width: 5.0,
            ),
            MatrixInput(
              //matrixBorderColor takes default color - black
              textAlign: TextAlign.center,
              enabled: true,
              readOnly: false,
              width: 60,
              matrixController: r0c2,
              keyboardType: TextInputType.number,
              style: TextStyle(
                fontSize: 25.0,
                color: Colors.green,
                fontWeight: FontWeight.bold,
              ),
            ),
          ],
        ),
      ),
    );
  }
}

```

- 4x4 Matrix

![pic2](https://user-images.githubusercontent.com/19472506/120332263-3d888580-c2f7-11eb-8348-37d4877d8d85.png)


- 5x5 Matrix

![pic3](https://user-images.githubusercontent.com/19472506/120332276-40837600-c2f7-11eb-8caa-729db20dc26e.png)
